yakumo.keystone.v2

Package yakumo :: Package keystone :: Package v2 |
[hide private]
[frames] | no frames]

# Package v2

source code

Sub client class for Identity V2 API

Submodules | [hide private]
yakumo.keystone.v2.endpoint: Resource class and its manager for endpoints in Identity V2 API yakumo.keystone.v2.project: Resource class and its manager for projects in Identity V2 API yakumo.keystone.v2.role: Resource class and its manager for roles in Identity V2 API yakumo.keystone.v2.service: Resource class and its manager for services in Identity V2 API yakumo.keystone.v2.user: Resource class and its manager for users in Identity V2 API

Classes | [hide private]
| Client

Variables | [hide private]
| __package__ = ``'``yakumo.keystone.v2``'``